summaryrefslogtreecommitdiff
path: root/odb/odb.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'odb/odb.cxx')
-rw-r--r--odb/odb.cxx7
1 files changed, 6 insertions, 1 deletions
diff --git a/odb/odb.cxx b/odb/odb.cxx
index a1beccf..075cf53 100644
--- a/odb/odb.cxx
+++ b/odb/odb.cxx
@@ -530,7 +530,12 @@ main (int argc, char* argv[])
<< "# include <tr1/memory>" << endl
<< "#endif" << endl;
- // Standard containers traits.
+ // Standard pointer traits.
+ //
+ os << "#include <odb/pointer-traits.hxx>" << endl
+ << "#include <odb/tr1-pointer-traits.hxx>" << endl;
+
+ // Standard container traits.
//
os << "#include <odb/container-traits.hxx>" << endl;
}